@@ -1,3 +1,5 @@
+use std::ffi::c_void;
+
 use libloading::{Library, Symbol};
 
 macro_rules! find_library {
@@ -73,10 +75,14 @@ lazy_static::lazy_static! {
 }
 
 pub(crate) struct LuaShared {
+	pub lual_newstate: Symbol<'static, unsafe extern "C-unwind" fn() -> LuaState>,
+	pub lual_openlibs: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState)>,
 	pub lual_loadfile: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, path: LuaString) -> i32>,
 	pub lual_loadstring: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, path: LuaString) -> i32>,
+	pub lual_loadbuffer: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, buff: LuaString, sz: LuaSize, name: LuaString) -> i32>,
 	pub lua_getfield: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32, k: LuaString)>,
 	pub lua_pushvalue: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32)>,
+	pub lua_pushlightuserdata: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, data: *mut c_void)>,
 	pub lua_pushboolean: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, bool: i32)>,
 	pub lua_tolstring: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32, out_size: *mut LuaSize) -> LuaString>,
 	pub lua_pcall: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, nargs: i32, nresults: i32, errfunc: i32) -> i32>,
@@ -98,6 +104,7 @@ pub(crate) struct LuaShared {
 	pub lual_checkinteger: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, arg: i32) -> LuaInt>,
 	pub lual_checklstring: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, arg: i32, out_size: *mut LuaSize) -> LuaString>,
 	pub lua_toboolean: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32) -> i32>,
+	pub lual_checktype: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32, r#type: i32)>,
 	pub lua_setmetatable: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, index: i32) -> i32>,
 	pub lua_pushinteger: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, int: LuaInt)>,
 	pub lua_pushnumber: Symbol<'static, unsafe extern "C-unwind" fn(state: LuaState, int: LuaNumber)>,
@@ -132,8 +139,13 @@ impl LuaShared {
 			}
 
 			Self {
+				lual_newstate: find_symbol!("luaL_newstate"),
+				lual_openlibs: find_symbol!("luaL_openlibs"),
+				lua_pushlightuserdata: find_symbol!("lua_pushlightuserdata"),
+				lual_checktype: find_symbol!("luaL_checktype"),
 				lual_loadfile: find_symbol!("luaL_loadfile"),
 				lual_loadstring: find_symbol!("luaL_loadstring"),
+				lual_loadbuffer: find_symbol!("luaL_loadbuffer"),
 				lua_getfield: find_symbol!("lua_getfield"),
 				lua_pushvalue: find_symbol!("lua_pushvalue"),
 				lua_pushboolean: find_symbol!("lua_pushboolean"),
